@@ -12,6 +12,10 @@ use base qw(graphincludes::extractor);
 use graphincludes::params;
 use File::Basename qw(dirname);
 
+sub get_default_sysincludes {
+  return ('/usr/include');
+}
+
 sub pattern { '\.([ch](pp|xx|\+\+)?|C|H|cc|hh)$' }
 
 sub getdeps {
