@@ -36,8 +36,9 @@ sub filelabel {
     $file =~ s/\.[^.]*$//;
     return $file;
   } elsif ($level == 2) {
-    if ($file =~ m!(.*)/.*!) {
-      return $1;
+    (undef, my $dirname, my $filename) = splitpath($file);
+    if ($dirname ne '') {
+      return $dirname;
     } else {
       return '<' . $self->filelabel($file, $level - 1) . '>';
     }
