@@ -9,14 +9,17 @@ use warnings;
 
 use base qw(graphincludes::project::default);
 
+use File::Spec::Functions qw(splitpath);
+
 use graphincludes::params;
 
 sub filelabel {
   my $self = shift;
   my ($file) = @_;
   $file =~ s/^$self->{PFXSTRIP}// if defined $self->{PFXSTRIP};
-  $file =~ s!(?:.*/)?([^/]*)\.[^./]*$!$1!;
-  return $file;
+  (undef, my $dirname, my $filename) = splitpath($file);
+  $filename =~ s!\.[^.]*$!!;	# strip suffix
+  return $filename;
 }
 
 sub getdeps {
@@ -24,8 +27,14 @@ sub getdeps {
   my %deps;
 
   while (<>) {
-    if (m!^\s*#\s*include\s*[<"](?:.*/)?([^/]+)(\.[^.]+)[>"]!) {
+    if (m!^\s*#\s*include\s*[<"](.+)[>"]!) {
       my $dstfile = $1;
+
+      # strip dirs
+      (undef, undef, $dstfile) = splitpath($dstfile);
+
+      $dstfile =~ s!\.[^.]*$!!;	# strip suffix
+
       if (grep { $self->filelabel($_) eq $dstfile } @{$self->{FILES}}) {
 	push (@{$deps{$self->{NODEIDS}->{$self->filelabel($ARGV)}}},
 	      $self->{NODEIDS}->{$self->filelabel($dstfile)});
